==> newland-toubiz-sync-neos-dev-release-1.10.2-280845.zip: Classes/Domain/Model/Category.php <==
<?php
namespace Newland\Toubiz\Sync\Neos\Domain\Model;

/*
 * This file is part of the "toubiz-sync-neos" package.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 */

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use Neos\Flow\Annotations as Flow;
use Newland\Toubiz\Sync\Neos\Translation\TranslatableEntity;

/**
 * @Flow\Entity
 * @ORM\Table(indexes={
 *      @ORM\Index(name="newland_toubiz_sync_neos_category_import_ident", columns={"language", "originalid"})
 * })
 */
class Category extends AbstractEntity
{

    use TranslatableEntity;

    /** @var string */
    protected $title;

    /**
     * @ORM\ManyToMany(targetEntity="\Newland\Toubiz\Sync\Neos\Domain\Model\Article", mappedBy="categories",
     *     fetch="LAZY")
     * @var Collection<Article>
     */
    protected $articles;

    /**
     * @ORM\ManyToMany(targetEntity="\Newland\Toubiz\Sync\Neos\Domain\Model\Event", mappedBy="categories", fetch="LAZY")
     * @var Collection<Event>
     */
    protected $events;

    public function __construct()
    {
        $this->events = new ArrayCollection();
        $this->articles = new ArrayCollection();
    }

    public function setTitle($title): void
    {
        $this->title = $title;
    }

    public function getTitle(): string
    {
        return $this->title;
    }

    public function getArticles(): Collection
    {
        return $this->articles;
    }

    public function getEvents(): Collection
    {
        return $this->events;
    }
}

==> newland-toubiz-sync-neos-dev-release-1.13.0-66a508.zip: Classes/Domain/Model/Category.php <==
<?php
namespace Newland\Toubiz\Sync\Neos\Domain\Model;

/*
 * This file is part of the "toubiz-sync-neos" package.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 */

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use Neos\Flow\Annotations as Flow;
use Newland\Toubiz\Sync\Neos\Orm\Uuid\CustomUuidGeneration;
use Newland\Toubiz\Sync\Neos\Orm\Uuid\UuidGenerator;
use Newland\Toubiz\Sync\Neos\Translation\TranslatableEntity;
use Ramsey\Uuid\Uuid;
use Ramsey\Uuid\UuidInterface;

/**
 * @Flow\Entity
 * @ORM\Table(indexes={
 *      @ORM\Index(name="newland_toubiz_sync_neos_category_import_ident", columns={"language", "originalid"})
 * })
 */
class Category extends AbstractEntity implements CustomUuidGeneration
{
    use TranslatableEntity;

    public function generateUuid(): UuidInterface
    {
        return UuidGenerator::uuidFromProperties([ $this->originalId, $this->language ]);
    }

    /** @var string */
    protected $title;

    /**
     * @ORM\ManyToMany(targetEntity="\Newland\Toubiz\Sync\Neos\Domain\Model\Article", mappedBy="categories",
     *     fetch="LAZY")
     * @ORM\JoinTable(name="newland_toubiz_sync_neos_domain_model_article_categories_join")
     * @var Collection<Article>
     */
    protected $articles;

    /**
     * @ORM\ManyToMany(targetEntity="\Newland\Toubiz\Sync\Neos\Domain\Model\Event", mappedBy="categories", fetch="LAZY")
     * @ORM\JoinTable(name="newland_toubiz_sync_neos_domain_model_event_categories_join")
     * @var Collection<Event>
     */
    protected $events;

    public function __construct()
    {
        $this->events = new ArrayCollection();
        $this->articles = new ArrayCollection();
    }

    public function setTitle($title): void
    {
        $this->title = $title;
    }

    public function getTitle(): string
    {
        return $this->title;
    }

    public function getArticles(): Collection
    {
        return $this->articles;
    }

    public function getEvents(): Collection
    {
        return $this->events;
    }
}
